% RBC model used in replication files of 
% Andreasen, Fernández-Villaverde, Rubio-Ramírez (2018): "The Pruned State-Space System for Non-Linear DSGE Models: Theory and Empirical Applications", Review of Economic Studies, 85(1):1-49.
% Adapted by Willi Mutschler (@wmutschl, willi@mutschler.eu)
% =========================================================================
% Copyright (C) 2020-2021 Dynare Team
%
% This file is part of Dynare.
%
% Dynare is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% Dynare is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
% =========================================================================

% All the variables in "model" are in logarithm following Dynare guidance Video
% This file is to estimate the regime 1 70-99 00-22
% File is base on the one used in Dynare Summer School 2021
% Haofeng Zhou, 2024 April 25th
% =========================================================================


var iB  $i^B: Liquid Interest Rate$
    iD  $i^D: Illiquid Interest Rate$
    v   $V: Debt Level$
    t   $T: Tax Level$
    p   $P: Inflation$
    g   $G: Government Spending Level$
    y   $Y: Output Level$
    c   $C: Consumption Level$
    zi  $Z1: Philiphs Curve Variable 1$
    zii $Z2: Philiphs Curve Variable 2$
    RR  $Real Interst Rate Serves As Moment$
    VoT $V over T denotes the Debt-Tax Ratio Serves as Moment$
    ;
    
predetermined_variables iB v;

varexo e_g $Government Spending Shock$
    ;
    
parameters Gss      $G in steady state$
    Yss             $Y in Steady state$
    Css             $C in Steady state$
    Vss             $V in Steady state$
    Tss             $T in Steady state$
    Pss             $P in Steady state$
    IBss            $I^B in Steady state$
    IDss            $I^D in Steady state$    
    beta            $Discount Factor$
    epsi            $epsilon in markup$
    theta           $1-price adjusting ratio$
    gamma           $mu_v(Vss)/u_c(Css)$
    sig             $Risk Aversion of consumption and the inverse is IES$
    mu              $Risk Aversion for Convenience Benefit$
    eta             $R-A for labor supply$
    rho             $Persistency of Spending Shock$
    ip              $Tayloy Rule on Inflation$
    sy              $Tax Rule on output$
    alp             $Tax rule on debt alpha$
    ;       

Gss           = 0.2;
Yss           = 1;
Css           = Yss-Gss;
Vss           = 0.6231;
Tss           = 0.1078; 
Pss           = 1; 
IBss          = 1.0192;
IDss          = IBss/0.9955;
beta          = (1/IDss)^(1/4);
epsi          = 1/0.36;
theta         = 0.734;
gamma         = 0.0045;
sig           = 2;
mu            = 2;
eta           = 2;
rho           = 0.9;
ip            = 1.5;
sy            = 0.27;
alp           = 0.07;


model;    
0 = beta*exp(iD)*(exp(c(+1))^(-sig))*(exp(p(+1))^(-1))-exp(c)^(-sig);
0 = exp(t)+exp(v)-exp(g)-exp(v(-1))*exp(iD(-1))*(exp(p)^(-1));
0 = exp(iB)*(exp(iD)^(-1))-1+gamma*((1-mu)*((1-sig)^(-1))*((exp(v)-Vss)/Vss)*(Css/(exp(c)-Css)));
0 = exp(y)-exp(g)-exp(c);
0 = (exp(c)^(-sig))*exp(y)*(exp(y)^(eta))*((exp(c)^(-sig))^(-1))+theta*beta*exp(zi(+1))*(exp(p(+1))^(epsi));
0 = (exp(c)^(-sig))*exp(y)+theta*beta*exp(zii(+1))*(exp(p(+1))^(epsi-1));
0 = ((1-theta)*(((epsi)*((epsi-1)^(-1)))*((exp(zi))*((exp(zii))^(-1)))*exp(p))^(1-epsi)+theta)^(1/(1-epsi))-exp(p);
0 = exp(iB)/IBss-(exp(p)/Pss)^(ip);
0 = exp(t)/Tss-((exp(v)/Tss)^(alp))*((exp(y)/Yss)^(sy));
0 = -log(exp(g)/Gss)+rho*log(exp(g(-1))/Gss)+e_g/100;
0 = RR-exp(iB)/exp(p);
0 = VoT-exp(v)/exp(t);

end;

steady_state_model;
IB  = IBss;
ID  = IB/(1-gamma);
V   = Vss;
T   = Tss;
P   = Pss;
G   = Gss;
Y   = Yss;
C   = Css;
Zi  = (C^(-sig))*Y*(Y^(mu))*(C^(sig))/(1-theta*beta);
Zii = (C^(-sig))*Y/(1-theta*beta);
RR  = IB/P;
VoT = V/T;

iB=log(IB);%
iD=log(ID);
v=log(V);
t=log(T);
p=log(P);
g=log(G);
y=log(Y);
c=log(C);
zi=log(Zi);
zii=log(Zii);



end;